instrumenttools.Violin
======================

.. abjad-lineage:: abjad.tools.instrumenttools.Violin.Violin.Violin

.. autoclass:: abjad.tools.instrumenttools.Violin.Violin.Violin
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Violin.Violin.Violin.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Violin.Violin.Violin.__repr__
   :noindex:
